; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.


;-| Super Motions |--------------------------------------------------------
[Command]
name = "kiretu"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command] 
name = "kisyou"   ;Same name as above
command = ~D, DF, F, D, DF, F, a
time = 20

[Command] 
name = "ranbu"   
command = ~D, DF, F, D, DF, F, y
time = 20

[Command] 
name = "onikubi"   
command = ~D, DF, F, D, DF, F, z
time = 20

[Command] 
name = "ennma"   
command = ~D, DF, F, D, DF, F, b
time = 20

[Command] 
name = "ougi"   
command = ~D, DF, F, D, DF, F, c
time = 20

[Command] 
name = "togakubi"   
command = ~D,z+c
time = 10

;-| Special Motions |------------------------------------------------------
[Command]
name = "kien_x"
command = ~F, D, $F, x

[Command]
name = "kien_y"
command = ~F, D, $F, y

[Command]
name = "kien_z"
command = ~F, D, $F, z

[Command]
name = "623_a"
command = ~F, D, $F, a

[Command]
name = "623_b"
command = ~F, D, $F, b

[Command]
name = "623_c"
command = ~F, D, $F, c

[Command]
name = "cross_x"
command = ~B, D, F, x

[Command]
name = "cross_y"
command = ~B, D, F, y
[Command]
name = "cross_z"
command = ~B, D, F, z

[Command]
name = "iai_x"
command = ~D, DB, B, x

[Command]
name = "iai_y"
command = ~D, DB, B, y

[Command]
name = "iai_z"
command = ~D, DB, B, z

[Command]
name = "iai_a"
command = ~D, DB, B, a

[Command]
name = "iai_b"
command = ~D, DB, B, b

[Command]
name = "iai_c"
command = ~D, DB, B, c

[Command]
name = "gomen_x"
command = ~F,B,x

[Command]
name = "gomen_y"
command = ~F,B,y

[Command]
name = "gomen_z"
command = ~F,B,z

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


[Command]
name = "r_a"
command = /F , a
time = 1


[Command]
name = "r_c"
command = /F ,c
time = 1

[Command]
name = "r_x"
command = /F ,x
time = 1

[Command]
name = "r_y"
command = /F ,y
time = 1

[Command]
name = "r_z"
command = /F , z
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Sa
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = command = "kiretu"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact

;---------------------------------------------------------------------------
;SLVĎa
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3100
triggerall = command = "kisyou"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact

;---------------------------------------------------------------------------
;S_
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3200
triggerall = command = "ranbu"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact

;---------------------------------------------------------------------------
;SЂ˂
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3300
triggerall = command = "onikubi"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = P2statetype != L
trigger1 = ctrl
trigger2 = statetype != L
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact

;---------------------------------------------------------------------------
;腖
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3400
triggerall = command = "ennma"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact

;---------------------------------------------------------------------------
;Ƃ񂳂炵
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3500
triggerall = command = "togakubi"
triggerall = power >= 1000
triggerall = P2stateno = [5100,5110]
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;SLŎEa
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3600
triggerall = command = "ougi"
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact

;===========================================================================
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;Sa@
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = command = "kien_x"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;Sa@
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = command = "kien_y"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;Sa@
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = command = "kien_z"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;SE@
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1300
triggerall = command = "623_a"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;SE@
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1300
triggerall = command = "623_b"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;SE@
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1300
triggerall = command = "623_c"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------

;NXSa@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1100
triggerall = command = "cross_x"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;NXSa@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1100
triggerall = command = "cross_y"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;NXSa@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1100
triggerall = command = "cross_z"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;a@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1200
triggerall = command = "iai_x"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;a@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1200
triggerall = command = "iai_y"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;a@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1200
triggerall = command = "iai_z"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;Ⴊ݋a@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1250
triggerall = command = "iai_a"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;Ⴊ݋a@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1250
triggerall = command = "iai_b"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;Ⴊ݋a@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1250
triggerall = command = "iai_c"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
;---------------------------------------------------------------------------
;؂̂ČƁ@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1400
triggerall = command = "gomen_x"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;---------------------------------------------------------------------------
;؂̂ČƁ@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1400
triggerall = command = "gomen_y"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
;---------------------------------------------------------------------------
;؂̂ČƁ@
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1400
triggerall = command = "gomen_z"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [300,399])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;P
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;K
[State -1, Kung Fu Throw]
type = ChangeState
value = 900
triggerall = command = "c"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;o[p`
[State -1, Stand Light Punch]
type = ChangeState
value = 205
triggerall = command = "r_x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 205)
trigger2 = time > 7
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand m Punch
;o[o
[State -1, Stand m Punch]
type = ChangeState
value = 215
triggerall = command = "r_y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,205]) || (stateno = [250,260])
trigger2 = movecontact


;---------------------------------------------------------------------------
;o[p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 225
triggerall = command = "r_z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,215]) || (stateno = [250,275])
trigger2 = movecontact

;---------------------------------------------------------------------------

;Stand Light Kick
;o[LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 255
triggerall = command = "r_a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 205)
trigger2 = movecontact

;---------------------------------------------------------------------------
;o[LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 275
triggerall = command = "r_c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,225]) || (stateno = [250,265])
trigger2 = movecontact

;---------------------------------------------------------------------------


;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 7
trigger2 = movecontact
trigger3 = stateno = 100


;---------------------------------------------------------------------------
;Stand m Punch
[State -1, Stand m Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,205]) ||(stateno = [250,260])
trigger2 = movecontact
trigger3 = stateno = 100


;---------------------------------------------------------------------------
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,210]) || (stateno = [250,270])
trigger2 = movecontact
trigger3 = stateno = 100

;---------------------------------------------------------------------------

;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 250
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200)
trigger2 = movecontact
trigger3 = stateno = 100

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing m Kick]
type = ChangeState
value = 260
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,210]) || (stateno = 250)
trigger2 = movecontact
trigger3 = stateno = 100

;---------------------------------------------------------------------------
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 270
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,220]) || (stateno = [250,260])
trigger2 = movecontact
trigger3 = stateno = 100

;---------------------------------------------------------------------------


;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 300
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 300) 
trigger2 = movecontact 
trigger2 = time >10

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊݒp`
[State -1, Crouching m Punch]
type = ChangeState
value = 310
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 300) || (stateno = 350)
trigger2 = movecontact 

;---------------------------------------------------------------------------
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 320
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = [300,310]) || (stateno = [350,370])
trigger2 = movecontact 

;---------------------------------------------------------------------------

;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 350
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 300) 
trigger2 = movecontact 

;---------------------------------------------------------------------------
;Crouching Strong Kick
;ႪݒLbN
[State -1, Crouching m Kick]
type = ChangeState
value = 360
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = [300,310]) || (stateno = 350)
trigger2 = movecontact 

;---------------------------------------------------------------------------
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 370
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = [300,360])
trigger2 = movecontact

;---------------------------------------------------------------------------

;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = statetime >= 7
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Punch
;󒆒ς
[State -1, Jump m Punch]
type = ChangeState
value = 410
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 450 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
[State -1, Jump Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [400,420]) || (stateno = [450,470]) ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------

;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 450
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆒LbN
[State -1, Jump m Kick]
type = ChangeState
value = 460
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [400,410]) || (stateno = 450) ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 470
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [400,460]) 
trigger2 = movecontact
